.. image:: http://www.repostatus.org/badges/latest/active.svg
    :target: http://www.repostatus.org/#active
    :alt: Project Status: Active — The project has reached a stable, usable
          state and is being actively developed.

.. image:: https://www.codefactor.io/repository/github/meaningful-data/sdmxthon/badge
   :target: https://www.codefactor.io/repository/github/meaningful-data/sdmxthon
   :alt: CodeFactor

.. image:: https://img.shields.io/badge/License-Apache%202.0-blue.svg
   :target: https://opensource.org/licenses/Apache-2.0
   :alt: License

.. image:: https://img.shields.io/pypi/pyversions/sdmxthon
    :alt: Python Version

.. image:: https://github.com/Meaningful-Data/sdmxthon/actions/workflows/ci.yml/badge.svg
    :target: https://github.com/Meaningful-Data/sdmxthon/actions/workflows/ci.yml
    :alt: Tests


########
SDMXthon
########

SDMXthon is an open source Python library implementing the `SDMX 2.1 information model <https://sdmx.org/wp-content/uploads/SDMX_2-1-1_SECTION_2_InformationModel_201108.pdf>`_

Documentation can be found in the `Docs page <https://docs.sdmxthon.meaningfuldata.eu/>`_

========
Features
========

1. SDMX message reader/writer
2. Pandas connector (SDMX to Pandas, Pandas to SDMX)
3. SDMX data validation
4. SDMX metadata validation

`View Changelog <https://github.com/Meaningful-Data/sdmxthon/blob/master/Changelog.rst>`_
